"use client"

import { useState, useEffect } from "react"
import { useAuth } from "@/context/auth-context"
import { useRouter } from "next/navigation"
import NavBar from "@/components/nav-bar"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import {
  BarChart,
  Bar,
  XAxis,
  YAxis,
  CartesianGrid,
  Tooltip,
  Legend,
  ResponsiveContainer,
  PieChart,
  Pie,
  Cell,
} from "recharts"
import { Users, Award, BookOpen, TestTube } from "lucide-react"

export default function DashboardPage() {
  const { user, isLoading } = useAuth()
  const router = useRouter()
  const [users, setUsers] = useState([])
  const [scores, setScores] = useState([])
  const [isDataLoading, setIsDataLoading] = useState(true)

  useEffect(() => {
    if (!isLoading && (!user || user.role !== "admin")) {
      router.push("/")
    }
  }, [user, isLoading, router])

  useEffect(() => {
    const fetchData = async () => {
      try {
        setIsDataLoading(true)

        // Charger les utilisateurs
        const usersResponse = await fetch("/api/users")
        const usersData = await usersResponse.json()
        setUsers(usersData)

        // Charger les scores
        const scoresResponse = await fetch("/api/scores")
        const scoresData = await scoresResponse.json()
        setScores(scoresData)
      } catch (error) {
        console.error("Erreur lors du chargement des données:", error)
      } finally {
        setIsDataLoading(false)
      }
    }

    if (user && user.role === "admin") {
      fetchData()
    }
  }, [user])

  if (isLoading || isDataLoading) {
    return (
      <div className="min-h-screen flex items-center justify-center">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-route-blue"></div>
      </div>
    )
  }

  if (!user || user.role !== "admin") {
    return null
  }

  // Préparer les données pour les graphiques
  const examScores = scores.filter((score) => score.examType === "exam")
  const exerciseScores = scores.filter((score) => score.examType === "exercise")

  const userScoreData = users.map((user) => {
    const userScores = scores.filter((score) => score.userId === user.id)
    const averageScore =
      userScores.length > 0
        ? userScores.reduce((acc, curr) => acc + (curr.score / curr.maxScore) * 100, 0) / userScores.length
        : 0

    return {
      name: user.name,
      averageScore: Math.round(averageScore),
    }
  })

  const examTypeData = [
    { name: "Examens", count: examScores.length },
    { name: "Exercices", count: exerciseScores.length },
  ]

  const COLORS = ["#007AFF", "#FF3B30", "#FFCC00", "#34C759"]

  return (
    <div className="min-h-screen route-pattern">
      <NavBar />

      <div className="route-header">
        <div className="container mx-auto px-4">
          <h1 className="text-3xl font-bold text-center text-[#007AFF]">Tableau de Bord</h1>
          <div className="road-line"></div>
        </div>
      </div>

      <div className="container mx-auto px-4 py-8">
        <Tabs defaultValue="overview" className="space-y-6">
          <TabsList className="grid grid-cols-3 w-full max-w-md mx-auto">
            <TabsTrigger value="overview">Vue d'ensemble</TabsTrigger>
            <TabsTrigger value="users">Utilisateurs</TabsTrigger>
            <TabsTrigger value="scores">Scores</TabsTrigger>
          </TabsList>

          <TabsContent value="overview">
            <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6 mb-8">
              <Card>
                <CardHeader className="flex flex-row items-center justify-between pb-2">
                  <CardTitle className="text-sm font-medium">Total Utilisateurs</CardTitle>
                  <Users className="h-4 w-4 text-muted-foreground" />
                </CardHeader>
                <CardContent>
                  <div className="text-2xl font-bold">{users.length}</div>
                </CardContent>
              </Card>

              <Card>
                <CardHeader className="flex flex-row items-center justify-between pb-2">
                  <CardTitle className="text-sm font-medium">Total Examens</CardTitle>
                  <TestTube className="h-4 w-4 text-muted-foreground" />
                </CardHeader>
                <CardContent>
                  <div className="text-2xl font-bold">{examScores.length}</div>
                </CardContent>
              </Card>

              <Card>
                <CardHeader className="flex flex-row items-center justify-between pb-2">
                  <CardTitle className="text-sm font-medium">Total Exercices</CardTitle>
                  <BookOpen className="h-4 w-4 text-muted-foreground" />
                </CardHeader>
                <CardContent>
                  <div className="text-2xl font-bold">{exerciseScores.length}</div>
                </CardContent>
              </Card>

              <Card>
                <CardHeader className="flex flex-row items-center justify-between pb-2">
                  <CardTitle className="text-sm font-medium">Score Moyen</CardTitle>
                  <Award className="h-4 w-4 text-muted-foreground" />
                </CardHeader>
                <CardContent>
                  <div className="text-2xl font-bold">
                    {scores.length > 0
                      ? Math.round(
                          scores.reduce((acc, curr) => acc + (curr.score / curr.maxScore) * 100, 0) / scores.length,
                        )
                      : 0}
                    %
                  </div>
                </CardContent>
              </Card>
            </div>

            <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
              <Card>
                <CardHeader>
                  <CardTitle>Scores moyens par utilisateur</CardTitle>
                  <CardDescription>Pourcentage de réussite moyen</CardDescription>
                </CardHeader>
                <CardContent className="h-80">
                  <ResponsiveContainer width="100%" height="100%">
                    <BarChart data={userScoreData} margin={{ top: 20, right: 30, left: 20, bottom: 60 }}>
                      <CartesianGrid strokeDasharray="3 3" />
                      <XAxis dataKey="name" angle={-45} textAnchor="end" height={60} />
                      <YAxis domain={[0, 100]} />
                      <Tooltip formatter={(value) => [`${value}%`, "Score moyen"]} />
                      <Legend />
                      <Bar dataKey="averageScore" name="Score moyen (%)" fill="#007AFF" />
                    </BarChart>
                  </ResponsiveContainer>
                </CardContent>
              </Card>

              <Card>
                <CardHeader>
                  <CardTitle>Répartition des tests</CardTitle>
                  <CardDescription>Examens vs Exercices</CardDescription>
                </CardHeader>
                <CardContent className="h-80">
                  <ResponsiveContainer width="100%" height="100%">
                    <PieChart>
                      <Pie
                        data={examTypeData}
                        cx="50%"
                        cy="50%"
                        labelLine={false}
                        label={({ name, percent }) => `${name}: ${(percent * 100).toFixed(0)}%`}
                        outerRadius={80}
                        fill="#8884d8"
                        dataKey="count"
                      >
                        {examTypeData.map((entry, index) => (
                          <Cell key={`cell-${index}`} fill={COLORS[index % COLORS.length]} />
                        ))}
                      </Pie>
                      <Tooltip formatter={(value) => [value, "Nombre"]} />
                      <Legend />
                    </PieChart>
                  </ResponsiveContainer>
                </CardContent>
              </Card>
            </div>
          </TabsContent>

          <TabsContent value="users">
            <Card>
              <CardHeader>
                <CardTitle>Liste des utilisateurs</CardTitle>
                <CardDescription>Tous les utilisateurs enregistrés sur la plateforme</CardDescription>
              </CardHeader>
              <CardContent>
                <div className="overflow-x-auto">
                  <table className="w-full border-collapse">
                    <thead>
                      <tr className="border-b">
                        <th className="text-left py-3 px-4">ID</th>
                        <th className="text-left py-3 px-4">Nom</th>
                        <th className="text-left py-3 px-4">Nom d'utilisateur</th>
                        <th className="text-left py-3 px-4">Email</th>
                        <th className="text-left py-3 px-4">Rôle</th>
                        <th className="text-left py-3 px-4">Tests passés</th>
                        <th className="text-left py-3 px-4">Date d'inscription</th>
                      </tr>
                    </thead>
                    <tbody>
                      {users.map((user) => (
                        <tr key={user.id} className="border-b hover:bg-gray-50">
                          <td className="py-3 px-4">{user.id}</td>
                          <td className="py-3 px-4">{user.name}</td>
                          <td className="py-3 px-4">{user.username}</td>
                          <td className="py-3 px-4">{user.email || "-"}</td>
                          <td className="py-3 px-4">
                            <span
                              className={`px-2 py-1 rounded-full text-xs ${
                                user.role === "admin"
                                  ? "bg-route-red/10 text-route-red"
                                  : "bg-route-blue/10 text-route-blue"
                              }`}
                            >
                              {user.role}
                            </span>
                          </td>
                          <td className="py-3 px-4">{user._count.scores}</td>
                          <td className="py-3 px-4">{new Date(user.createdAt).toLocaleDateString()}</td>
                        </tr>
                      ))}
                    </tbody>
                  </table>
                </div>
              </CardContent>
            </Card>
          </TabsContent>

          <TabsContent value="scores">
            <Card>
              <CardHeader>
                <CardTitle>Historique des scores</CardTitle>
                <CardDescription>Tous les tests passés sur la plateforme</CardDescription>
              </CardHeader>
              <CardContent>
                <div className="overflow-x-auto">
                  <table className="w-full border-collapse">
                    <thead>
                      <tr className="border-b">
                        <th className="text-left py-3 px-4">ID</th>
                        <th className="text-left py-3 px-4">Utilisateur</th>
                        <th className="text-left py-3 px-4">Type</th>
                        <th className="text-left py-3 px-4">ID Examen</th>
                        <th className="text-left py-3 px-4">Score</th>
                        <th className="text-left py-3 px-4">Pourcentage</th>
                        <th className="text-left py-3 px-4">Date</th>
                      </tr>
                    </thead>
                    <tbody>
                      {scores.map((score) => (
                        <tr key={score.id} className="border-b hover:bg-gray-50">
                          <td className="py-3 px-4">{score.id}</td>
                          <td className="py-3 px-4">{score.user.name}</td>
                          <td className="py-3 px-4">
                            <span
                              className={`px-2 py-1 rounded-full text-xs ${
                                score.examType === "exam"
                                  ? "bg-route-red/10 text-route-red"
                                  : "bg-route-blue/10 text-route-blue"
                              }`}
                            >
                              {score.examType === "exam" ? "Examen" : "Exercice"}
                            </span>
                          </td>
                          <td className="py-3 px-4">{score.examId}</td>
                          <td className="py-3 px-4">
                            {score.score} / {score.maxScore}
                          </td>
                          <td className="py-3 px-4">
                            <div className="flex items-center">
                              <div className="w-full bg-gray-200 rounded-full h-2.5 mr-2">
                                <div
                                  className={`h-2.5 rounded-full ${
                                    (score.score / score.maxScore) >= 0.8
                                      ? "bg-route-green"
                                      : score.score / score.maxScore >= 0.5
                                        ? "bg-route-yellow"
                                        : "bg-route-red"
                                  }`}
                                  style={{ width: `${(score.score / score.maxScore) * 100}%` }}
                                ></div>
                              </div>
                              <span>{Math.round((score.score / score.maxScore) * 100)}%</span>
                            </div>
                          </td>
                          <td className="py-3 px-4">{new Date(score.passedAt).toLocaleString()}</td>
                        </tr>
                      ))}
                    </tbody>
                  </table>
                </div>
              </CardContent>
            </Card>
          </TabsContent>
        </Tabs>
      </div>
    </div>
  )
}
